/**
 * @fileoverview 版面の縦横座標を返す
 * @author Adobe Systems, Kenshi Muto &lt;kmuto@debian.org&gt;
 * @requires libCommon.jsx
*/

/*
    Copyright:
    2008 Kenshi Muto <kmuto@debian.org>
    2007 Adobe Systems

   ADOBE INDESIGN CS3 SCRIPTING GUIDE: JAVASCRIPT を改変。
*/
#include "../libs/libCommon.jsx"

/**
 * 指定のページの版面座標をgeometricBounds形式で返す
 * @param {Document} document ドキュメントオブジェクト
 * @param {Page} page ページオブジェクト
 * @type Long[4]
 * @return 版面の座標
*/
function getBoundsOfPage(document, page) {
  // 指定のページ内の版面部分を返す
  var backunit = toMmMode(document);

  var pagewidth = document.documentPreferences.pageWidth;
  var pageheight = document.documentPreferences.pageHeight;
  var x1, y1, x2, y2;
  if (page.side == PageSideOptions.leftHand) {
    // 左ページならフリップ
    x2 = page.marginPreferences.left;
    x1 = page.marginPreferences.right;
  } else {
    x1 = page.marginPreferences.left;
    x2 = page.marginPreferences.right;
  }
  y1 = page.marginPreferences.top;
  x2 = pagewidth - x2;
  y2 = pageheight - page.marginPreferences.bottom;

  revertMmMode(document, backunit);

  return [ y1, x1, y2, x2 ];
}
